Average Model Data
avg_model_data.RdCalculate monthly average from raw model data across the entire provided timeseries. This is built specifically for MOM6 output, but would work on any rasterStack of gridded data.
avg_model_data.RdCalculate monthly average from raw model data across the entire provided timeseries. This is built specifically for MOM6 output, but would work on any rasterStack of gridded data.