Calculate Model Confidence Score for each Species
calculate_model_confidence.RdCalculates mean and standard deviation of the model confidence score
Value
a data frame including mean and standard deviation of data quality scores for each attribute with the length of the number of attributes.
Examples
if (FALSE) { # \dontrun{
species.data.list <- split(data, data$Species)
#data is the combined data frame of
#all model confidence spreadsheets from scorers
species.conf <- lapply(species.data.list, model.confidence)
speciesMC <- do.call(rbind, species.conf)
#this combines the list of vectors into a data.frame
} # }