Make Map or Timeseries of Total Species-Specific Exposure
make_total_exposure.RdUses the logic rule from CVA1.0 to combine variable-specific exposures to create a total exposure map or timeseries
Arguments
- type
designates desired output, must equal 'map' or 'timeseries'
- variable_exposure
If
type == 'map', a rasterStack output frommake_variable_exposure(type == 'map'). Iftype == 'timeseries', the matrix output frommake_variable_exposure(type == 'timeseries').- count_all
TRUE/FALSE to use
weightsandwThresholdto subset variables to only important variables- weights
output from
combine_weights- a vector of variable weights in ensemble SDM- weight_threshold
numeric value used to subset weights, variables with weights less to or equal to this value will be excluded from total exposure calculation