Normalize Model Data
normalize_model_data.RdNormalize model data across the entire provided timeseries using a z-score
Arguments
- raw_list
List of output rasters from
pull_hindorpull_forecast. Alternatively, a list of rasters containing gridded data to be normalized, with each entry in the list containing a rasterStack of a timeseries of environmental data to be normalized.- avg_list, sd_list
List of output rasters from
avg_model_dataandsd_env, respectively. Alternatively, averages and standard deviations of desired gridded datasets. Should be a list of rasterStacks, with each entry in the list containing the rasterStack for a different variable.- short_names
vector of simplified variable names to help name resulting raster files.